@@ -7,7 +7,7 @@ class CircleResponse:
         self.code = code
         self.headers = headers
 
-        self.data = json.loads(body)
+        self.data = json.loads(body)["data"]
 
     @property
     def idempotency_key(self):
