@@ -9,4 +9,6 @@ class CreateableAPIResource(APIResource):
         requestor = api_requestor.APIRequestor(api_key)
         url = cls.class_url()
         response, api_key = requestor.request("post", url, params)
-        return util.convert_to_circle_object(response, api_key)
+        return util.convert_to_circle_object(
+            response, api_key, klass_name=cls.OBJECT_NAME
+        )
